/*
 *	@(#)reg56321.h	1.2 01/10/17
 */

/**************************************************************************
**									  *
**  FILE	:  reg56321.h						  *
**									  *
**  DESCRIPTION :  Include file with memory mapped I/O definitions	  *
**		   for the DSP56321.					  *
**									  *
**  COPYRIGHT	:  2001 TASKING, Inc.					  *
**									  *
**************************************************************************/

#ifndef _REG56321_H
#define _REG56321_H

#include <irq563xx.h>

/*--------------------------------------------------------------------------------

	OnCE

--------------------------------------------------------------------------------*/

#define OGDBR  (*(int _X*)    	0xFFFFFC) /* OnCE GDB Register			*/


/*--------------------------------------------------------------------------------

	Port A / BIU

--------------------------------------------------------------------------------*/

typedef union				/* Port A Bus Control Register		*/
{
	struct
	{	unsigned BA0W: 5;  /*  0: Area 0 Waitstates			*/
		unsigned BA1W: 5;  /*  5: Area 1 Waitstates			*/
		unsigned BA2W: 3;  /* 10: Area 2 Waitstates			*/
		unsigned BA3W: 3;  /* 13: Area 3 Waitstates			*/
		unsigned BDFW: 5;  /* 16: Default Area Waitstates		*/
		int	 BBS : 1;  /* 21: Bus State				*/
		int	 BLH : 1;  /* 22: Bus Lock Hold				*/
		int	 BRH : 1;  /* 23: Bus Request Hold			*/
	} B;

	int I;

} bcr_type;


typedef union				/* Port A Address Attribute Register	*/
{
	struct
	{	unsigned BAT : 2;  /*  0: Bus Access Type			*/
		int      BAAP: 1;  /*  2: Bus Address Attribute Polarity	*/
		int      BPEN: 1;  /*  3: Bus Program Memory Enable		*/
		int      BXEN: 1;  /*  4: Bus X Data Memory Enable		*/
		int      BYEN: 1;  /*  5: Bus Y Data Memory Enable		*/
		int          : 1;  /*  6: Reserved				*/
		int      BPAC: 1;  /*  7: Bus Packing Enable			*/
		unsigned BNC : 4;  /*  8: Bus Number of Address Bits to Compare	*/
		unsigned BAC : 12; /* 12: Bus Address to Compare		*/
	} B;

	int I;

} aar_type;


#define BCR   (*(volatile bcr_type _X*)	0xFFFFFB) /* Port A Bus Control Register	*/
#define AAR0  (*(aar_type _X*)    	0xFFFFF9) /* Port A Address Attribute Register 0*/
#define AAR1  (*(aar_type _X*)    	0xFFFFF8) /* Port A Address Attribute Register 1*/
#define AAR2  (*(aar_type _X*)    	0xFFFFF7) /* Port A Address Attribute Register 2*/
#define AAR3  (*(aar_type _X*)    	0xFFFFF6) /* Port A Address Attribute Register 3*/
#define IDR   (*(int _X*)	    	0xFFFFF5) /* Port A ID Register			*/


/*--------------------------------------------------------------------------------

	DMA

--------------------------------------------------------------------------------*/

typedef union				/* DMA Status Register			*/
{
	struct
	{	int	 DTD0: 1;  /*  0: DMA Channel 0 Transfer Done Status	*/
		int	 DTD1: 1;  /*  1: DMA Channel 1 Transfer Done Status	*/
		int	 DTD2: 1;  /*  2: DMA Channel 2 Transfer Done Status	*/
		int	 DTD3: 1;  /*  3: DMA Channel 3 Transfer Done Status	*/
		int	 DTD4: 1;  /*  4: DMA Channel 4 Transfer Done Status	*/
		int	 DTD5: 1;  /*  5: DMA Channel 5 Transfer Done Status	*/
		unsigned     : 2;  /*  6: Reserved				*/
		int	 DACT: 1;  /*  8: DMA Active				*/
		unsigned DCH : 3;  /*  9: DMA Active Channel			*/
		unsigned     :12;  /* 12: Reserved				*/
	} B;

	int I;

} dstr_type;

typedef union				/* DMA Control Register			*/
{
	struct
	{	unsigned DSS : 2;  /*  0: DMA Source Space			*/
		unsigned DDS : 2;  /*  2: DMA Destination Space			*/
		unsigned DAM : 6;  /*  4: DMA Address Mode			*/
		int	 D3D : 1;  /* 10: DMA Three Dimensional Mode		*/
		unsigned DRS : 5;  /* 11: DMA Request Source			*/
		int	 DCON: 1;  /* 16: DMA Continuous Mode Enable		*/
		unsigned DPR : 2;  /* 17: DMA Channel Priority			*/
		unsigned DTM : 3;  /* 19: DMA Transfer Mode			*/
		int	 DIE : 1;  /* 22: DMA Interrupt Enable			*/
		int	 DE  : 1;  /* 23: DMA Channel Enable				*/
	} B;

	int I;

} dctrl_type;


#define DSTR  (*(volatile dstr_type _X*)0xFFFFF4) /* DMA Status Register	*/

#define DOR0  (*(int _X*)	  0xFFFFF3) /* DMA Offset Register 0		*/
#define DOR1  (*(int _X*)	  0xFFFFF2) /* DMA Offset Register 1		*/
#define DOR2  (*(int _X*)	  0xFFFFF1) /* DMA Offset Register 2		*/
#define DOR3  (*(int _X*)	  0xFFFFF0) /* DMA Offset Register 3		*/

#define DSR0 (*(int* volatile _X*)0xFFFFEF) /* DMA Source Address Reg. 0	*/
#define DDR0 (*(int* volatile _X*)0xFFFFEE) /* DMA Destination Address Reg. 0	*/
#define DCO0 (*(volatile int  _X*)0xFFFFED) /* DMA Counter 0			*/
#define DCR0 (*(dctrl_type _X*)   0xFFFFEC) /* DMA Control Register 0		*/

#define DSR1 (*(int* volatile _X*)0xFFFFEB) /* DMA Source Address Reg. 1	*/
#define DDR1 (*(int* volatile _X*)0xFFFFEA) /* DMA Destination Address Reg. 1	*/
#define DCO1 (*(volatile int  _X*)0xFFFFE9) /* DMA Counter 1			*/
#define DCR1 (*(dctrl_type _X*)   0xFFFFE8) /* DMA Control Register 1		*/

#define DSR2 (*(int* volatile _X*)0xFFFFE7) /* DMA Source Address Reg. 2	*/
#define DDR2 (*(int* volatile _X*)0xFFFFE6) /* DMA Destination Address Reg. 2	*/
#define DCO2 (*(volatile int  _X*)0xFFFFE5) /* DMA Counter 2			*/
#define DCR2 (*(dctrl_type _X*)   0xFFFFE4) /* DMA Control Register 2		*/

#define DSR3 (*(int* volatile _X*)0xFFFFE3) /* DMA Source Address Reg. 3	*/
#define DDR3 (*(int* volatile _X*)0xFFFFE2) /* DMA Destination Address Reg. 3	*/
#define DCO3 (*(volatile int  _X*)0xFFFFE1) /* DMA Counter 3			*/
#define DCR3 (*(dctrl_type _X*)   0xFFFFE0) /* DMA Control Register 3		*/

#define DSR4 (*(int* volatile _X*)0xFFFFDF) /* DMA Source Address Reg. 4	*/
#define DDR4 (*(int* volatile _X*)0xFFFFDE) /* DMA Destination Address Reg. 4	*/
#define DCO4 (*(volatile int  _X*)0xFFFFDD) /* DMA Counter 4			*/
#define DCR4 (*(dctrl_type _X*)   0xFFFFDC) /* DMA Control Register 4		*/

#define DSR5 (*(int* volatile _X*)0xFFFFDB) /* DMA Source Address Reg. 5	*/
#define DDR5 (*(int* volatile _X*)0xFFFFDA) /* DMA Destination Address Reg. 5	*/
#define DCO5 (*(volatile int  _X*)0xFFFFD9) /* DMA Counter 5			*/
#define DCR5 (*(dctrl_type _X*)   0xFFFFD8) /* DMA Control Register 5		*/


/*--------------------------------------------------------------------------------

	CLKGEN / DPLL

--------------------------------------------------------------------------------*/

typedef union				/* DPLL Clock Control Register		*/
{
	struct
	{	int	     : 1;  /*  0: Reserved				*/
		int	 PSTP: 1;  /*  1: DPLL Stop State Control		*/
		int	 XTLD: 1;  /*  2: XTAL Disable				*/
		int	 PEN : 1;  /*  3: DPLL Enable				*/
		unsigned DF  : 3;  /*  4: Division Factor			*/
		unsigned     : 17; /*  7: Reserved				*/
	} B;

	int I;

} dccr_type;


typedef union				/* DPLL Static Control Register		*/
{
	struct
	{	unsigned MFI : 4;  /*  0: Multiplication Factor Integer		*/
		unsigned MFN : 7;  /*  4: Multiplication Factor Numerator	*/
		unsigned MFD : 7;  /* 11: Multiplication Factor Denominator	*/
		unsigned PDF : 4;  /* 18: Pre-Division Factor			*/
		int	 PLM : 1;  /* 22: Phase Lock Mode			*/
		int	 BRM0: 1;  /* 23: Binary Rate Modulation Order		*/
	} B;

	int I;

} dscr_type;


#define DCCR (*(dccr_type _X*)    0xFFFFD1) /* DPLL Clock Control Register	*/
#define DSCR (*(dscr_type _X*)    0xFFFFD0) /* DPLL Static Control Register	*/


/*--------------------------------------------------------------------------------

	Port B

--------------------------------------------------------------------------------*/

#define HDR   (*(volatile int _X*) 0xFFFFC9) /* Host GPIO Data Register		*/
#define HDDR  (*(int _X*)	   0xFFFFC8) /* Host GPIO Data Direction Reg.	*/


/*--------------------------------------------------------------------------------

	Host Interface HI08

--------------------------------------------------------------------------------*/

typedef union				 /* Host Control Register		*/
{
	struct
	{	int	 HRIE: 1;  /*  0: Host Receive Interrupt Enable		*/
		int	 HTIE: 1;  /*  1: Host Transmit Interrupt Enable	*/
		int	 HCIE: 1;  /*  2: Host Command Interrupt Enable		*/
		int	 HF2 : 1;  /*  3: Host Flag 2				*/
		int	 HF3 : 1;  /*  4: Host Flag 3				*/
		unsigned     : 11; /*  5: Reserved				*/
	} B;

	int I;

} hcr_type;


typedef union				/* Host Status Register			*/
{
	struct
	{	int	 HRDF: 1;  /*  0: Host Receive Data Full		*/
		int	 HTDE: 1;  /*  1: Host Transmit Data Empty		*/
		int	 HCP : 1;  /*  2: Host Command Pending			*/
		int	 HF0 : 1;  /*  3: Host Flag 0				*/
		int	 HF1 : 1;  /*  4: Host Flag 1				*/
		unsigned     : 11; /*  5: Reserved				*/
	} B;

	int I;

} hsr_type;


typedef union				 /* Host Port Control Register		*/
{
	struct
	{	int	 HGEN : 1;  /*  0: Host GPIO Port Enable		*/
		int	 HA8EN: 1;  /*  1: Host Address Line 8 Enable		*/
		int	 HA9EN: 1;  /*  2: Host Address Line 9 Enable		*/
		int	 HCSEN: 1;  /*  3: Host Chip Select Enable		*/
		int	 HREN : 1;  /*  4: Host Request Enable			*/
		int	 HAEN : 1;  /*  5: Host Acknowledge Enable		*/
		int	 HEN  : 1;  /*  6: Host Enable				*/
		int	      : 1;  /*  7: Reserved				*/
		int	 HROD : 1;  /*  8: Host Request Open Drain		*/
		int	 HDSP : 1;  /*  9: Host Data Strobe Polarity		*/
		int	 HASP : 1;  /* 10: Host Address Strobe Polarity		*/
		int	 HMUX : 1;  /* 11: Host Multiplexed Bus			*/
		int	 HDDS : 1;  /* 12: Host Dual Data Strobe		*/
		int	 HCSP : 1;  /* 13: Host Chip Select Polarity		*/
		int	 HRP  : 1;  /* 14: Host Request Polarity		*/
		int	 HAP  : 1;  /* 15: Host Acknowledge Polarity		*/
	} B;

	int I;

} hpcr_type;


#define HTX   (*(volatile int _X*)	   0xFFFFC7) /* Host Data Transmit Reg. */
#define HRX   (*(const volatile int _X*)   0xFFFFC6) /* Host Data Receive Reg.  */
#define HBAR  (*(int _X*)	   	   0xFFFFC5) /* Host Base Address Reg.	*/
#define HPCR  (*(hpcr_type _X*)	           0xFFFFC4) /* Host Port Control Reg.	*/
#define HSR   (*(const volatile hsr_type _X*)0xFFFFC3) /* Host Status Register  */
#define HCR   (*(hcr_type _X*)		   0xFFFFC2) /* Host Control Register   */


/*--------------------------------------------------------------------------------

	Port C

--------------------------------------------------------------------------------*/

#define PCRC  (*(int _X*)   	  0xFFFFBF) /* Port C Control Register		*/
#define PRRC  (*(int _X*)   	  0xFFFFBE) /* Port C Direction Register	*/
#define PDRC  (*(volatile int _X*)0xFFFFBD) /* Port C GPIO Data Register	*/


/*--------------------------------------------------------------------------------

	ESSI

--------------------------------------------------------------------------------*/

typedef union				/* ESSI Control Register A		*/
{
	struct
	{	unsigned PM  : 8;  /*  0: Prescale Modulus Select		*/
		unsigned     : 3;  /*  8: Reserved				*/
		int	 PSR : 1;  /* 11: Prescale Range			*/
		unsigned DC  : 5;  /* 12: Frame Rate Divider Control		*/
		int	     : 1;  /* 17: Reserved				*/
		int	 ALC : 1;  /* 18: Alignment Control			*/
		unsigned WL  : 3;  /* 19: Word Length Control			*/
		int	 SSC1: 1;  /* 22: Select SC1				*/
		int	     : 1;  /* 23: Reserved				*/
	} B;

	int I;

} cra_type;


typedef union				/* ESSI Control Register B		*/
{
	struct
	{	int	 OF0 : 1;  /*  0: Serial Output Flag 0			*/
		int	 OF1 : 1;  /*  1: Serial Output Flag 1			*/
		int	 SCD0: 1;  /*  2: Serial Control 0 Direction		*/
		int	 SCD1: 1;  /*  3: Serial Control 1 Direction		*/
		int	 SCD2: 1;  /*  4: Serial Control 2 Direction		*/
		int	 SCKD: 1;  /*  5: Clock Source Direction		*/
		int	 SHFD: 1;  /*  6: Shift Direction			*/
		int	 FSL0: 1;  /*  7: Frame Sync Length 0			*/
		int	 FSL1: 1;  /*  8: Frame Sync Length 1			*/
		int	 FSR : 1;  /*  9: Frame Sync Relative Timing		*/
		int	 FSP : 1;  /* 10: Frame Sync Polarity			*/
		int	 CKP : 1;  /* 11: Clock Polarity			*/
		int	 SYN : 1;  /* 12: Sync/Async Control			*/
		int	 MOD : 1;  /* 13: Mode Select				*/
		int	 TE2 : 1;  /* 14: Transmit #2 Enable			*/
		int	 TE1 : 1;  /* 15: Transmit #1 Enable			*/
		int	 TE0 : 1;  /* 16: Transmit #0 Enable			*/
		int	 SRE : 1;  /* 17: ESSI Receive Enable			*/
		int	 STIE: 1;  /* 18: ESSI Transmit Interrupt Enable	*/
		int	 SRIE: 1;  /* 19: ESSI Receive Interrupt Enable		*/
		int	 TLIE: 1;  /* 20: ESSI Transmit Last Slot Int. Enable	*/
		int	 RLIE: 1;  /* 21: ESSI Receive Last Slot Int. Enable	*/
		int	 TEIE: 1;  /* 22: ESSI Transmit Exception Int. Enable	*/
		int	 REIE: 1;  /* 23: ESSI Receive Exception Int. Enable	*/
	} B;

	int I;

} crb_type;


typedef union				/* ESSI Status Register			*/
{
	struct
	{	int	 IF0 : 1;  /*  0: Serial Input Flag 0			*/
		int	 IF1 : 1;  /*  1: Serial Input Flag 1			*/
		int	 TFS : 1;  /*  2: Transmit Frame Sync			*/
		int	 RFS : 1;  /*  3: Receive Frame Sync			*/
		int	 TUE : 1;  /*  4: Transmitter Underrun Error		*/
		int	 ROE : 1;  /*  5: Receiver Overrun Error		*/
		int	 TDE : 1;  /*  6: Transmit Data Register Empty		*/
		int	 RDF : 1;  /*  7: Receive Data Register Full		*/
		int	     : 16; /*  8: Reserved				*/
	} B;

	int I;

} sr_type;


/*--------------------------------------------------------------------------------

	ESSI 0

--------------------------------------------------------------------------------*/

#define TX00  (*(volatile _fract _X*)	   0xFFFFBC) /* Transmit Data Reg. 0	*/
#define TX01  (*(volatile _fract _X*)	   0xFFFFBB) /* Transmit Data Reg. 1	*/
#define TX02  (*(volatile _fract _X*)	   0xFFFFBA) /* Transmit Data Reg. 2	*/
#define TSR0  (*(int _X*)		   0xFFFFB9) /* Time Slot Register 	*/
#define RX0   (*(const volatile _fract _X*)0xFFFFB8) /* Receive Data Register	*/
#define SSISR0 (*(volatile sr_type _X*)	   0xFFFFB7) /* Status Register		*/
#define CRB0  (*(crb_type _X*)		   0xFFFFB6) /* Control Register B 	*/
#define CRA0  (*(cra_type _X*)		   0xFFFFB5) /* Control Register A 	*/
#define TSMA0 (*(int _X*)	       	   0xFFFFB4) /* Transmit Slot Mask Reg A*/
#define TSMB0 (*(int _X*)		   0xFFFFB3) /* Transmit Slot Mask Reg B*/
#define RSMA0 (*(int _X*)		   0xFFFFB2) /* Receive Slot Mask Reg A */
#define RSMB0 (*(int _X*)		   0xFFFFB1) /* Receive Slot Mask Reg B	*/


/*--------------------------------------------------------------------------------

	Port D

--------------------------------------------------------------------------------*/

#define PCRD  (*(int _X*)		   0xFFFFAF) /* Port D Control Register	*/
#define PRRD  (*(int _X*)		   0xFFFFAE) /* Port D Direction Reg.	*/
#define PDRD  (*(volatile int _X*)	   0xFFFFAD) /* Port D GPIO Data Reg.   */


/*--------------------------------------------------------------------------------

	ESSI 1

--------------------------------------------------------------------------------*/

#define TX10  (*(volatile _fract _X*)	   0xFFFFAC) /* Transmit Data Reg. 0	*/
#define TX11  (*(volatile _fract _X*)	   0xFFFFAB) /* Transmit Data Reg. 1	*/
#define TX12  (*(volatile _fract _X*)	   0xFFFFAA) /* Transmit Data Reg. 2	*/
#define TSR1  (*(int _X*)	     	   0xFFFFA9) /* Time Slot Register 	*/
#define RX1   (*(const volatile _fract _X*)0xFFFFA8) /* Receive Data Register	*/
#define SSISR1 (*(volatile sr_type _X*)	   0xFFFFA7) /* Status Register		*/
#define CRB1  (*(crb_type _X*)		   0xFFFFA6) /* Control Register B 	*/
#define CRA1  (*(cra_type _X*)		   0xFFFFA5) /* Control Register A 	*/
#define TSMA1 (*(int _X*)	       	   0xFFFFA4) /* Transmit Slot Mask Reg A*/
#define TSMB1 (*(int _X*)		   0xFFFFA3) /* Transmit Slot Mask Reg B*/
#define RSMA1 (*(int _X*)		   0xFFFFA2) /* Receive Slot Mask Reg A	*/
#define RSMB1 (*(int _X*)		   0xFFFFA1) /* Receive Slot Mask Reg B	*/


/*--------------------------------------------------------------------------------

	Port E

--------------------------------------------------------------------------------*/

#define PCRE  (*(int _X*)		   0xFFFF9F) /* Port E Control Register	*/
#define PRRE  (*(int _X*)		   0xFFFF9E) /* Port E Direction Reg.	*/
#define PDRE  (*(volatile int _X*)	   0xFFFF9D) /* Port E GPIO Data Reg.	*/


/*--------------------------------------------------------------------------------

	SCI

--------------------------------------------------------------------------------*/

typedef union				/* SCI Control Register			*/
{
	struct
	{	unsigned WDS : 3;  /*  0: Word select 0-2			*/
		int	 SSFTD:1;  /*  3: SCI Shift direction			*/
		int	 SBK : 1;  /*  4: Send Break				*/
		int	 WAKE: 1;  /*  5: Wake-up Mode Select			*/
		int	 RWU : 1;  /*  6: Receiver Wake-up Enable		*/
		int	 WOMS: 1;  /*  7: Wired-OR Mode Select			*/
		int	 RE  : 1;  /*  8: Receiver Enable			*/
		int	 TE  : 1;  /*  9: Transmitter Enable			*/
		int	 ILIE: 1;  /* 10: Idle Line Interrupt Enable		*/
		int	 RIE : 1;  /* 11: SCI Receive Interrupt Enable		*/
		int	 TIE : 1;  /* 12: SCI Transmit Interrupt Enable		*/
		int	 TMIE: 1;  /* 13: Timer Interrupt Enable		*/
		int	 STIR: 1;  /* 14: Timer Interrupt Rate			*/
		int	 SCKP: 1;  /* 15: SCI Clock Polarity			*/
		int	 RXIE: 1;  /* 16: Receive with Exception Int. Enable	*/
		int	     : 7;  /* 17: Reserved				*/
	} B;

	int I;

} scr_type;


typedef union				/* SCI Status Register			*/
{
	struct
	{	int	 TRNE: 1;  /*  0: Transmitter Empty			*/
		int	 TDRE: 1;  /*  1: Transmit Data Register Empty		*/
		int	 RDRF: 1;  /*  2: Receive Data Register Full		*/
		int	 IDLE: 1;  /*  3: Idle Line				*/
		int	 OR  : 1;  /*  4: Overrun Error				*/
		int	 PE  : 1;  /*  5: Parity Error				*/
		int	 FE  : 1;  /*  6: Framing Error				*/
		int	 R8  : 1;  /*  7: Received Bit 8			*/
		int	     : 16; /*  8: Reserved				*/
	} B;

	int I;

} ssr_type;


typedef union				/* SCI Clock Control Register		*/
{
	struct
	{	unsigned CD  : 12; /*  0: Clock Divider				*/
		int	 COD : 1;  /* 12: Clock Out Divider			*/
		int	 SCP : 1;  /* 13: Clock Prescaler			*/
		int	 RCM : 1;  /* 14: Receive Clock Mode Source		*/
		int	 TCM : 1;  /* 15: Transmit Clock Source			*/
		int	     : 8;  /* 16: Reserved				*/
	} B;

	int I;

} sccr_type;


#define SCR   (*(scr_type _X*)	        0xFFFF9C) /* SCI Control Register  	*/
#define SCCR  (*(sccr_type _X*)	        0xFFFF9B) /* SCI Clock Control Register	*/
#define SRXH  (*(const volatile int _X*)0xFFFF9A) /* SCI Receive Data Reg. Hi   */
#define SRXM  (*(const volatile int _X*)0xFFFF99) /* SCI Receive Data Reg. Mid  */
#define SRXL  (*(const volatile int _X*)0xFFFF98) /* SCI Receive Data Reg. Lo   */
#define STXH  (*(volatile int _X*)	0xFFFF97) /* SCI Transmit Data Reg. H	*/
#define STXM  (*(volatile int _X*)	0xFFFF96) /* SCI Transmit Data Reg. M	*/
#define STXL  (*(volatile int _X*)	0xFFFF95) /* SCI Transmit Data Reg. L	*/
#define STXA  (*(int _X*)		0xFFFF94) /* SCI Transmit Address Reg.  */
#define SSR   (*(volatile ssr_type _X*) 0xFFFF93) /* SCI Status Register        */


/*--------------------------------------------------------------------------------

	Triple Timer

--------------------------------------------------------------------------------*/

typedef union				/* Timer Prescaler Load Register	*/
{
	struct
	{
		unsigned PPV : 21; /*  0: Prescaler Preload Value		*/ 
		unsigned PCS :  2; /* 21: Prescaler Clock Source		*/
		int	     :  1; /* 23: Reserved				*/
	} B;

	int I;

} tplr_type;


typedef union				/* Timer Control/Status Register	*/
{
	struct
	{
		int	 TEN  : 1; /*  0: Timer Enable				*/
		int	 TOIE : 1; /*  1: Timer Overflow Interrupt Enable	*/
		int	 TCIE : 1; /*  2: Timer Compare Interrupt Enable	*/
		int	      : 1; /*  3: Reserved				*/
		unsigned TCTRL: 4; /*  4: Timer Control				*/
		int	 TINV : 1; /*  8: Timer Inverter			*/
		int	 TRM  : 1; /*  9: Timer Reload Mode			*/
		int	      : 1; /* 10: Reserved				*/
		int	 TDIR : 1; /* 11: Timer Direction			*/
		int	 TDI  : 1; /* 12: Timer Data Input			*/
		int	 TDO  : 1; /* 13: Timer Data Output			*/
		int	      : 1; /* 14: Reserved				*/
		int	 TPCE : 1; /* 15: Timer Prescaler Clock Enable		*/
		int	      : 4; /* 16: Reserved				*/
		int	 TOF  : 1; /* 20: Timer Overflow Flag			*/
		int	 TCF  : 1; /* 21: Timer Compare Flag			*/
		int	      : 2; /* 22: Reserved				*/
	} B;

	int I;

} tcsr_type;

#define TCSR0 (*(volatile tcsr_type _X*)  0xFFFF8F) /* Timer 0 Control/Status	*/
#define TLR0  (*(unsigned _X*)		  0xFFFF8E) /* Timer 0 Load Register	*/
#define TCPR0 (*(unsigned _X*)		  0xFFFF8D) /* Timer 0 Compare Register	*/
#define TCR0  (*(const volatile unsigned _X*)0xFFFF8C) /* Timer 0 Count Reg.    */

#define TCSR1 (*(volatile tcsr_type _X*)  0xFFFF8B) /* Timer 1 Control/Status 	*/
#define TLR1  (*(unsigned _X*)		  0xFFFF8A) /* Timer 1 Load Register	*/
#define TCPR1 (*(unsigned _X*)		  0xFFFF89) /* Timer 1 Compare Register	*/
#define TCR1  (*(const volatile unsigned _X*)0xFFFF88) /* Timer 1 Count Reg.	*/

#define TCSR2 (*(volatile tcsr_type _X*)  0xFFFF87) /* Timer 2 Control/Status 	*/
#define TLR2  (*(unsigned _X*)		  0xFFFF86) /* Timer 2 Load Register	*/
#define TCPR2 (*(unsigned _X*)		  0xFFFF85) /* Timer 2 Compare Register	*/
#define TCR2  (*(const volatile unsigned _X*)0xFFFF84) /* Timer 2 Count Reg.	*/

#define TPLR  (*(tplr_type _X*)		  0xFFFF83) /* Timer Prescaler Load Reg.*/
#define TPCR  (*(const volatile unsigned _X*)0xFFFF82) /* Timer Prescaler Count */


/*--------------------------------------------------------------------------------

	ENHANCED FILTER CO-PROCESSOR

--------------------------------------------------------------------------------*/

typedef union				/* EFCOP Decimation/Channel Count Reg.	*/
{
	struct
	{
		unsigned FCHL : 6; /*  0: Filter Channels Value			*/
		int	      : 2; /*  6: Reserved				*/
		unsigned FDCM : 4; /*  8: Filter Decimation Value		*/
		int	      :12; /* 12: Reserved				*/
	} B;

	int I;

} fdch_type;


typedef union				/* EFCOP ALU Control Register		*/
{
	struct
	{
		unsigned FSCL : 2; /*  0: Filter Scaling			*/
		unsigned FRM  : 2; /*  2: Filter Rounding Mode			*/
		int	 FSM  : 1; /*  4: Filter Saturation Mode		*/
		int	 FSA  : 1; /*  5: Filter 16-bit Arithmetic Mode		*/
		int	 FISL : 1; /*  6: Filter Input Scale			*/
		int	      :17; /*  7: Reserved				*/
	} B;

	int I;

} facr_type;


typedef union				/* EFCOP Control Status Register	*/
{
	struct
	{
		int	 FEN  : 1; /*  0: Filter Enable				*/
		int	 FLT  : 1; /*  1: Filter Type				*/
		int	 FADP : 1; /*  2: Filter Adaptive Mode			*/
		int	 FUPD : 1; /*  3: Filter Update				*/
		unsigned FOM  : 2; /*  4: Filter Operation Mode			*/
		int	 FMLC : 1; /*  6: Filter Multichannel Mode		*/
		int	 FPRC : 1; /*  7: Filter Processing State Init Mode	*/
		int	 FSCO : 1; /*  8: Filter Shared Coefficients Mode	*/
		int	      : 1; /*  9: Reserved				*/
		int	 FDIIE: 1; /* 10: Filter Data Input Interrupt Enable	*/
		int	 FDOIE: 1; /* 11: Filter Data Output Interrupt Enable	*/
		int	 FSAT : 1; /* 12: Filter Saturation			*/
		int	 FCONT: 1; /* 13: Filter Contention			*/
		int	 FDIBE: 1; /* 14: Filter Data Input Buffer Empty	*/
		int	 FDOBF: 1; /* 15: Filter Data Output Buffer Full	*/
		int	      : 8; /* 16: Reserved				*/
	} B;

	int I;

} fcsr_type;

#define FDCH (*(fdch_type	  _Y*)	0xFFFFB8) /* EFCOP Decimation/Channel Reg*/
#define FCBA (*(_fract	     _Y * _Y*)	0xFFFFB7) /* EFCOP Coefficient Base Addr */
#define FDBA (*(_fract	     _X	* _Y*)	0xFFFFB6) /* EFCOP Data Base Address	 */
#define FACR (*(facr_type	  _Y*)	0xFFFFB5) /* EFCOP ALU Control Reg.	 */
#define FCSR (*(volatile fcsr_type _Y*)	0xFFFFB4) /* EFCOP Control Status Reg.	 */
#define FCNT (*(unsigned	  _Y*)	0xFFFFB3) /* EFCOP Filter Count Reg.	 */
#define FKIR (*(_fract		  _Y*)	0xFFFFB2) /* EFCOP K-Constant Register	 */
#define FDOR (*(volatile _fract	  _Y*)	0xFFFFB1) /* EFCOP Data Output Reg.	 */
#define FDIR (*(_fract		  _Y*)	0xFFFFB0) /* EFCOP Data Input Register	 */


/*--------------------------------------------------------------------------------

	Exception Processing

--------------------------------------------------------------------------------*/

typedef union				/* Interrupt Priority Register Core	*/
{
	struct
	{	unsigned IAL : 2;  /*  0: IRQA Interrupt Priority Level		*/
		int	 IAT : 1;  /*  2: IRQA Trigger mode			*/
		unsigned IBL : 2;  /*  3: IRQB Interrupt Priority Level		*/
		int	 IBT : 1;  /*  5: IRQB Trigger mode			*/
		unsigned ICL : 2;  /*  6: IRQC Interrupt Priority Level		*/
		int	 ICT : 1;  /*  8: IRQC Trigger mode			*/
		unsigned IDL : 2;  /*  9: IRQD Interrupt Priority Level		*/
		int	 IDT : 1;  /* 11: IRQD Trigger mode			*/
		unsigned D0L : 2;  /* 12: DMA0 Interrupt Priority Level		*/
		unsigned D1L : 2;  /* 14: DMA1 Interrupt Priority Level		*/
		unsigned D2L : 2;  /* 16: DMA2 Interrupt Priority Level		*/
		unsigned D3L : 2;  /* 18: DMA3 Interrupt Priority Level		*/
		unsigned D4L : 2;  /* 20: DMA4 Interrupt Priority Level		*/
		unsigned D5L : 2;  /* 22: DMA5 Interrupt Priority Level		*/
	} B;

	int I;

} iprc_type;


typedef union				/* Interrupt Priority Register Periph.	*/
{
	struct
	{	unsigned HPL : 2;   /*	0: HI08	 Interrupt Priority Level	*/
		unsigned S0L : 2;   /*	2: ESSI0 Interrupt Priority Level	*/
		unsigned S1L : 2;   /*	4: ESSI1 Interrupt Priority Level	*/
		unsigned SCL : 2;   /*	6: SCI	 Interrupt Priority Level	*/
		unsigned T0L : 2;   /*	8: Timer Interrupt Priority Level	*/
		unsigned     : 14;  /* 10: Reserved				*/
	} B;

	int I;

} iprp_type;


#define IPRC  (*(iprc_type _X*) 0xFFFFFF) /* Interrupt Priority Register Core	*/
#define IPRP  (*(iprp_type _X*) 0xFFFFFE) /* Interrupt Priority Register Periph */

#endif	/* _REG56321_H */
